---
title: '[공지] 다날 본인인증 인증서 교체 관련 조치 일정 안내'
category: 공지사항
tags:
  - 공지사항
datetime: 2024-04-09T06:47:10.391Z
---

안녕하세요, 포트원 고객지원팀입니다.

3/25일자에 진행된 다날 PG사의 인증서 교체작업으로 인하여 특정 기기에서 본인인증이 불가합니다. \
현상이 발생되어 다날 측 조치 예정으로 확인되었습니다.서비스 운영간 참고부탁드립니다.

#### **다날 인증서 교체로 발생된 이슈 조치 일정안내**

- 이슈상황 : 안드로이드 OS버전 9버전 이하 기기에서 본인인증 오류 발생
- 작업 내용 : 최신 루트 인증서가 없는 경우 사용자가 가지고 있는 이전 버전 인증서로 handshake 될수 있도록 하는 인증서 추가
- 작업 일시 : 2024년 4월 2일(화요일) 오전 중
